Version class

Model to represent a version

Implemented types

Constructors

Version({required String version})
The version is passed as string in the format Major.Minor.Micro (Eg. 1.0.0)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String
final

Methods

compareTo(Version other) → int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited